The curve-apps repository and source distributions bundle several libraries that are
compatibly licensed.  We list these here.

.. list-table::
   :widths: 30 30 60
   :header-rows: 1

   * - Name
     - License
     - Description
   * - `geoh5py <https://github.com/MiraGeoscience/geoh5py>`_
     - LGPL-3.0-or-later
     - Python API for geoh5, an open file format for geoscientific data
   * - `numpy <https://github.com/numpy/numpy>`_
     - BSD-3-Clause
     - Fundamental package for array computing in Python
   * - `pydantic <https://docs.pydantic.dev/latest/>`_
     - MIT
     - Data validation using Python type hints.
   * - `scikit-image <https://github.com/scikit-image/scikit-image>`_
     - BSD-3-Clause
     - Image processing in Python
   * - `scipy <https://github.com/scipy/scipy>`_
     - BSD-3-Clause
     - Fundamental algorithms for scientific computing in Python
   * - `tqdm <https://github.com/tqdm>`_
     - MPL-2.0 or MIT
     - A Fast, Extensible Progress Bar for Python and CLI
